+++
title = "Systems and Signals Norms"
author = ["Thomas Dehaeze"]
draft = false
+++

Backlinks:

-   [Multivariable Control]({{< relref "multivariable_control" >}})

Tags
:

Resources:

-   ([Skogestad and Postlethwaite 2007](#orgf3c8b69))
-   ([Toivonen 2002](#orgb2755d2))
-   ([Zhang 2011](#org3e1b2ef))


## Definition {#definition}

A norm of \\(e\\) (which may be a vector, matrix, signal of system) is a real number, denoted \\(\\|e\\|\\), that satisfies the following properties:

1.  Non-negative: \\(\\|e\\| \ge 0\\)
2.  Positive: \\(\\|e\\| = 0 \Longleftrightarrow e = 0\\)
3.  Homogeneous: \\(\\|\alpha \cdot e\\| = |\alpha| \cdot \\|e\\|\\) for all complex scalars \\(\alpha\\)
4.  Triangle inequality: \\(\\|e\_1 + e\_2\\| \le \\|e\_1\\| + \\|e\_2\\|\\)


## Vector Norms {#vector-norms}

-   **Vector 1-norm (Sum Norm)**:
    \\[ \\|a\\|\_1 \triangleq \sum\_i |a\_i| \\]
-   **Vector 2-norm (Euclidean Norm)**:
    \\[ \\|a\\|\_2 \triangleq \sqrt{\sum\_i |a\_i|^2} \\]
-   **Vector p-norm**:
    \\[ \\|a\\|\_p \triangleq \left( \sum\_i |a\_i|^p \right)^{1/p} \\]
-   **Vector \\(\infty\text{-norm}\\) (Max Norm)**: ()
    \\[ \\|a\\|\_\infty \triangleq \max\_i |a\_i| \\]


## Matrix Norms {#matrix-norms}

<div class="examp">
  <div></div>

A norm on a matrix \\(\\|A\\|\\) is a matrix norm if, in addition to the four norm properties, it also satisfies the multiplicative property:
\\[ \\|AB\\| \le \\|A\\| \cdot \\|B\\| \\]

</div>

-   **Sum matrix norm**:
    \\[ \\|A\\|\_\text{sum} \triangleq \sum\_{i,j} |a\_{ij}| \\]
-   **Frobenius matrix norm (Euclidean Norm)**:
    \\[ \\|A\\|\_F \triangleq \sqrt{\sum\_{i,j} |a\_{ij}|^2} = \sqrt{\text{tr}(A^H A)} \\]
-   **Max element norm**: (which is not a _matrix_ norm)
    \\[ \\|A\\|\_\text{max} \triangleq \max\_{i,j} |a\_{ij}| \\]


## Induced Matrix Norms {#induced-matrix-norms}

Induced matrix norms are important because of their close relationship to signal amplification in systems.

Consider the figure below where \\(w\\) is the input vector, \\(z\\) the output vector and where the "amplification" or "gain" of the matrix \\(A\\) is defined by the ration \\(\\|z\\|/\\|w\\|\\).

{{< figure src="/ox-hugo/induced_matrix_norm.png" >}}

The maximum gain for all possible input directions is given by the **induced norm**:
\\[ \\|A\\|\_{ip} \triangleq \max\_{w \neq 0} \frac{\\|Aw\\|\_p}{\\|w\\|\_p} \\]

Thus, the induced norm gives the largest possible "amplification" of the matrix.
The following equivalent definition is also used:
\\[ \\|A\\|\_{ip} = \max\_{\\|w\\|\_p \le 1} \\|Aw\\|\_p \\]


## Signal Norms {#signal-norms}

For signals, we may compute the norm in two steps:

1.  "Sum up" the channels at a given time using a vector norm.
    For a scalar, we simply take the absolute value.
2.  "Sum up" in time using a temporal norm.

We normally use the same p-norm both for the vector and the signal.

-   **1-norm in time (Integral Absolute Error)**:
    \\[ \\|e(t)\\|\_1 = \int\_{-\infty}^{\infty} \sum\_i |e\_i(\tau)| d\tau \\]
-   **2-norm in time (Quadratic Norm)**:
    \\[ \\|e(t)\\|\_2 = \sqrt{\int\_{-\infty}^{\infty} \sum\_i |e\_i(\tau)|^2 d\tau} \\]
-   **\\(\infty\text{-norm}\\) in time (Peak value in time)**:
    \\[ \\|e(t)\\|\_\infty = \max\_\tau \left( \max\_i |e\_i(\tau)| \right) \\]
-   **Power-Norm or RMS-Norm**:
    \\[ \\|e(t)\\|\_\text{pow} = \lim\_{T\to \infty} \sqrt{\frac{1}{2T} \int\_{-T}^T \sum\_i |e\_i(\tau)|^2 d\tau} \\]


## Signal Interpretation of Various System Norms {#signal-interpretation-of-various-system-norms}


## System Norms {#system-norms}


### \\(\mathcal{H}\_\infty\\) Norm {#mathcal-h-infty--norm}

SISO Systems => absolute value => bode plot
MIMO Systems => singular value
Signal => maximum value


### \\(\mathcal{H}\_2\\) Norm {#mathcal-h-2--norm}

The \\(\mathcal{H}\_2\\) is very useful when combined to [Dynamic Error Budgeting]({{< relref "dynamic_error_budgeting" >}}).

As explained in ([Monkhorst 2004](#orgd47c42b)), the \\(\mathcal{H}\_2\\) norm has a stochastic interpretation:

> The squared \\(\mathcal{H}\_2\\) norm can be interpreted as the output variance of a system with zero mean white noise input.

Minimizing the \\(\mathcal{H}\_2\\) norm can be equivalent as minimizing the RMS value of some signals in the system.


## Link between signal and system norms {#link-between-signal-and-system-norms}


## Bibliography {#bibliography}

<a id="orgd47c42b"></a>Monkhorst, Wouter. 2004. “Dynamic Error Budgeting, a Design Approach.” Delft University.

<a id="orgf3c8b69"></a>Skogestad, Sigurd, and Ian Postlethwaite. 2007. _Multivariable Feedback Control: Analysis and Design_. John Wiley.

<a id="orgb2755d2"></a>Toivonen, Hannu T. 2002. “Robust Control Methods.” Abo Akademi University.

<a id="org3e1b2ef"></a>Zhang, Weidong. 2011. _Quantitative Process Control Theory_. CRC Press.
